==> haskell-some-1.0.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.6
visibility:           public
id:                   some-1.0.6-3jwijwQA4Ou8FJ8XRvJrOP
key:                  some-1.0.6-3jwijwQA4Ou8FJ8XRvJrOP
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  6e5f41530afbdde03beebe5d36301333
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/some-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.6-3jwijwQA4Ou8FJ8XRvJrOP
depends:
    base-4.17.2.1 base-orphans-0.9.1-2hOCfn2j6E6Chy4Kfvc1ON
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-some-1.0.6-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.6
visibility:           public
id:                   some-1.0.6-As3QDrvuxaqEQIbQQrudXS
key:                  some-1.0.6-As3QDrvuxaqEQIbQQrudXS
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  3edc521f72fb5cce0f124e997b17afb5
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/some-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.6-As3QDrvuxaqEQIbQQrudXS
depends:
    base-4.17.2.1 base-orphans-0.9.1-HJdmWkjGoqQKTZL3Y0OqDy
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
